Whistle
=======

`Whistle` provides simple python tools that allow your application components to communicate with each other by dispatching events and listening to them.

.. image:: https://travis-ci.org/python-whistle/whistle.svg?branch=master
    :target: https://travis-ci.org/python-whistle/whistle

.. image:: https://coveralls.io/repos/github/python-whistle/whistle/badge.svg?branch=master
    :target: https://coveralls.io/github/python-whistle/whistle?branch=master
    :alt: Coverage Status

.. image:: https://readthedocs.org/projects/whistle/badge/?version=latest
    :target: http://whistle.readthedocs.org/en/latest/?badge=latest
    :alt: Documentation Status


Install
:::::::

.. code-block:: shell

   pip install whistle


